@@ -1,7 +1,7 @@
 package Media::Info::Ffmpeg;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-01-28'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,12 +57,13 @@ sub get_media_info {
 
     my $info = {};
     $info->{duration}      = $1*3600+$2*60+$3 if $stderr =~ /^\s*Duration: (\d+):(\d+):(\d+\.\d+)/m;
+    $info->{rotate}        = $1 if $stderr =~ /^\s*rotate\s*:\s*(.+)/m;
 
     # XXX multiple video streams info
     if ($stderr =~ /^\s*Stream.+?: Video: (.+)/m) {
         my $video_info = $1;
         $video_info =~ /^(\w+)/; $info->{video_format} = uc($1);
-        $video_info =~ /(\d+)x(\d+)/ and do {
+        $video_info =~ /(\d+)x(\d+),/ and do {
             $info->{video_width}  = $1;
             $info->{video_height} = $2;
         };
@@ -96,7 +97,7 @@ Media::Info::Ffmpeg - Return information on media file/URL, using ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.005 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2017-07-10.
+This document describes version 0.006 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2019-01-28.
 
 =head1 SYNOPSIS
 
@@ -130,7 +131,7 @@ Sample result:
 
 Usage:
 
- get_media_info(%args) -> [status, msg, result, meta]
+ get_media_info(%args) -> [status, msg, payload, meta]
 
 Return information on media file/URL, using ffmpeg.
 
@@ -151,7 +152,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -183,7 +184,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
